
$ontext
                 **#########**  MYWAS-VALUE 2020  **########**

                     **$$$$$$$$$$  Version 9 $$$$$$$$$$**

                           Salinity Internalized(SI)


*  Updated 10-March-2020

   The model is applied to the case of Israel, encompassing the water and vegetative agricultural sectors, calibrated for 2015 data.
   The model is based on the Nodes concept, including two types of elements:
 + Nodes - which from them or to them water flows. It will be denoted by the indices j, i and n.
 + Pipeline - which the water flows through them. The pipelines are not defined specifically,
   but as variables of quantity and quality of water transferred between two Nodes (e.g. x from j to i).

 All types of Nodes are defined on the same set (j), and include the following elements:
 Natural sources: Fresh or Brackish water, Desalination planets: seawater (SWD), ground (brackish) water (GWD)
 and Reclaimed water (RWD).
 Demand areas: Urban or Agriculture, NWC (National Water Carrier) Junctions and Wastewater Treatment Plant (TP).

 The model is divided into three parts:
 1. Defining all the elements that make up the model.
 2. Formulating equations that define the model.
 3. Extracting the model's results.

 Main assumptions:
 + Customs duties on vegetative agricultural products have two tariffs and import quotas.
 + Sewage definition as an additive function.
 + Horizon Planning = 30 periods (years)
 + Discount factor stands on 3.5% as the rate of social time preference according to Nordhaus (2007)
 + Demand for water in the Urban sector as well as demand for agriculture produce in the local market increases by 1.8% per year according to the rate of population growth (ICBS 2017).
 + Salvage value for the natural freshwater sources is 0.
 + Allowed deficit of an aquifer at end of planning period is 5% of the entire capacity for each source.
 + Reclaimed water desalination takes into account a recovery rate of 85% (output/input).
 + RWD costs include tertiary treatment costs at all plants, excluding the Shafdan plant.
 + The salinity level of the outflowes from the desalination plants (all types) is 0.25 dS/m,
   compared to about 1 dS/m at the natural freshwater sources (there are some exceptions).
 + Treated wastewater can be discharged to nature only if it has undergone tertiary treatment.
 + The agriculture area of the Jeezrael Valley is special because of the assumption of allocation of water to fish ponds.
   This amount is 60 MCM per year constantly.

Units Legend:
 CM= Cubic Meter
 MCM= Million Cubic Meter
 M= Million
 Dunam= 1/10 Hectare
 dS/m= DeciSiemens per Meter

Abbreviations:
 FS- Fresh water Source
 BS- Brackish water Sourse
 GWD- Ground Water Desalination plant
 SWD- Sea Water Desalination plant
 WWTP/TP- WasteWater Treatment Plant
 RWD- Reclaimed Water Desalination plant
 NWC- National Water Carrier

 All the data used by the model are taken from the input Excel files,
 and all the results of the model are transferred to output Excel file.
 Any changes in the data must be done in the input Excel files.

***++++++ This model contains real data of all areas from MYWAS model as can be found at Reznik et al. (2016) ***++++++
$offtext

Set
   j Nodes (118)
   u Urban demand (divided into two sectors: households and industrial) (42)
   o Crop type (55)
   t Time (30)
   ;
* The next command is designed to enable flexibility used by the j set,
* i.e. each Node can be denoted by each of these letters.
 alias(j,i,n);

Scalars
   const        Constant- prevents division by zero /0.0000001/
   slr          The Salinity level of the rain (dS\m) /0.1/
   AQ_ENDV      Remaining portion of storage capacity of naturally enriched freshwater sources at the end of the planning period /0.05/
   P_AB         Price of water transferred to additional benefits (fishponds) ($\CM) /0.05/
 ;

Parameters

* Characters of Natural water sources (Fresh and Brackish):
   iscf(j)       Initial storage capacity (MCM)
   r(j,t)        Annual recharge (MCM\year)
   tst_cap(j)    Total storage capacity (MCM)
   vocf(j)       Variable freshwater-reservoir extraction cost in dependence of the elevation of the water head at the reservoir($\CM).
   occonst(j)    Operating constant cost of water pumping from Brackish water sources($\CM).
   Varpump_c(j)  Total account for Variable Pumping Cost which depending on the height of the reservoir($\CM).
   AQ_MAXDEF(j)  The Maximum deficit of an aquifer permitted at any time (%)
   slf(j,t)      Salinity level of a natural water source (dS\m)
* Other operating costs:
   vcp(j,i)      Conveyance cost per cubic meter for each pipe line between Nodes ($\CM)
   vdesc(j)      Desalination cost ($\CM)
   vch(j)        Wastewater Treatment cost ($\CM)
   sldp(j)       The salinity level of a desalination plant (dS\m)

* Note: desalination plants are defined with the following characters:
* For Ground Water Desalination plant (GWD) or Reclaimed Water Desalination (RWD),
* the features are similar to a Wastewater Treatment Plant: the desalinated amount is limited by the inflow and by the plant's capacity.
* If it is a Sea Water Desalination plant (SWD), it is limited only by its capacity since the source (the sea) is unlimited.

* The next 11 parameters define the Nodes types and the connections between Nodes.
   indf(j)       Set parameter for Fresh water sources
   inddp(j)      Set parameter for ALL types of Desalination plants
   indj(j)       Set parameter for NWC Junction- intersections of pipelines
   indd(j)       Set parameter for Urban District demands
   indh(j)       Set parameter for Wastewater Treatment plants
   inda(j)       Set parameter for Agriculture demand areas
   indb(j)       Set parameter for Brackish water sources
   inswd(j)      Set parameter for Sea Water Desalination plants
   inji(j,i)     Match parameter for a connections between two Nodes
   induc(j,u)    Match parameter for Urban (households or industrial) demand that is connected to districts
   insog(j)      A parameter that distinguishes between the Sea of Galilee and other freshwater sources
* The next eight parameters describe infrastructure capacities and the cost of expending them.
* Notes: pumping refers only to Natural sources; treatment refers only to wastewater treatment plants;
* and desalination refers only to desalination plants.
   cap(j,i)      Conveyance capacity of a Pipeline between two Nodes (MCM\year)
   pumpcap(j)    Pumping Capacity of a natural water source (MCM\year)
   treacap(j)    Treatment Capacity of a wastewater treatment plant (MCM\year)
   descap(j)     Desalination capacity of a desalination plant (MCM\year)

   extcc(j,i)    Cost of expanding pipeline capacity ($\CM)
   extpc(j)      Cost of expanding pumping capacity ($\CM)
   exttc(j)      Cost of expanding wastewater-treatment plant capacity ($\CM)
   extdc(j)      Cost of expanding desalination-plant capacity ($\CM)

*** Urban demand function parameters ***
   dpu(u,t)      The multiplying parameter of the inverse-demand function of water in the urban sector
   btu(u)        Inverse elasticity of the demand function for water in the urban sector
   epsu(u,t)     Minimum water quantity that determines the highest price threshold (MCM)
   maxsld(j)     Maximum Salinity permitted for the water supplied to an urban demand area (dS\M)
*** Wastewater parameters ***
   wwqc(u)       Wastewater Quantity Coefficient (wastewater\freshwater ratio)
   wwsc(j)       Salinity addition in the Wastewater (dS\m)
   rr(j)         Recovery rate for desalination plants (outflow\inflow ratio)- relevance only to RWDs

   df(t)         Discount factor (%)
   Salvcm(j)     Salvage value per CM for each fresh groundwater source ($\CM)- not in use
   WtoEnv_V(j)   Cost of water discharged to the environment equal to the tertiary treatment cost ($\CM)
   OU(j)         Other Utilities of water (mandatory amounts)
* The following four parameters are used to define specific times
   TLAST(t)      Shows last year of time sequence
   TFIRST(t)     Shows first year of time sequence
   TALLBLAST(t)  Shows all years but the last year of time sequence
   TALLBFIRST(t) Shows all years but the first year of the time sequence
* Agriculture parameters
   A(o,t)        The  multiplying parameter of the inverse demand function of vegetative agriculture produce of a crop supplied to the local market
   bta(o)        Inverse-demand elasticity for the inverse demand function of agriculture produce of a crop supplied to the local market
   epsa(o,t)     Minimum quantity of agriculture produce of a crop to the local market (Ton)
   indl(o)       Indicator for a crop that can be sold in the local market (1 or 0)

   miuL(o)       The share of produce that goes to the Local market (%)
   miuIn(o)      The share of produce that goes to the Industrial sector (%)
   miuEx(o)      The share of produce that goes to Export (%)
   Pin(o)        Crops' prices in the processing Industry sector  ($\Ton)
   PEx(o)        Crops' prices that are marketed to Export ($\Ton)
   PImA(o)       Agriculture produce Import Price without tariff ($\Ton)
   PImB(o)       Agriculture produce Import Price include tariff ($\Ton)
   Im_L(o)       Customs duty free quota (Ton)

*** Agriculture Production Function Parameters (VALUE model's parameters) ***
   po(o)         Crop price ($\Ton)- not in use
   E(j,o)        Maximum evapotranspiration
   Y_Max(j,o)    Maximum Yield (Ton\Dunam)
   phi(j,o)      PHI- Additive production function parameter- not in use (according to Kan et al. 2012)
   teta(j,o)     TETA- Multiply production function parameter (according to Shani et al. 2007)
   apa1(j,o)     ALPHA1- evapotranspiration function parameter
   apa2(j,o)     ALPHA2- evapotranspiration function parameter
   apa3(j,o)     ALPHA3- evapotranspiration function parameter
   apa4(j,o)     ALPHA4- evapotranspiration function parameter
   apa5(j,o)     ALPHA5- evapotranspiration function parameter
   psi(j,o)      PSI parameter- PMP linear cost-function element
   xsi(j,o)      XSI parameter- PMP quadratic cost-function element
   w(j,o)        Irrigation Water requirements (CM\Dunam\year)
   wr(j,o)       The rainfall that is relevance for irrigation (CM\Dunam\year)
   tl(j)         Total cultivatable land available in an Agricultural area (Dunam)
   is_lab(o)     Israeli labor crop growing requirements (day\Dunam)
   is_lp(o)      Israeli labor wage per day ($)
   for_lab(o)    Foreign labor crop growing requirements (day\Dunam)
   for_lp(o)     Foreign labor wage per day ($)
   pdc(j,o)      Fix growth costs($\Dunam)
   for_ll(j)     Foreign labor available in an agricultural area (days\year)
   indcp(j,o)    Match indicator that determines whether the crop can be grown in the area or not (1 or 0)
   slst(j)       Static Salinity level (dS\m)(used in the SE scenario)
   QAB(j)        Additional benefits (fishponds) quantities (MCM)
*** Initial Values ***
   xf_s(j,i,t)   Initial value for variable xf
   qfu_s(u,t)    Initial value for variable qfu
   qfa_s(j,t)    Initial value for variable qfa
   xg_s(j,o)     Initial value for variable xg
   Y_s(o,t)      Initial value for variable Y
   Im_s(o,t)     Initial value for variable Im
   ;

* The model data are taken from the GDX file that is connected to the Excel files.
* All the changes in the data need to be done in the Excel files and must be saved.
* There are two Excel files that contain the data for the MYWAS and VALUE modules.
* General data (MYWAS):
$call GDXXRW i=INPUT-WATER.xlsx o=MYWAS-VALUE_in.gdx index=Layout!a4
$GDXIN MYWAS-VALUE_in.gdx
$LOAD j u t o iscf slf AQ_MAXDEF sldp occonst vocf Varpump_c r
$LOAD indf inddp indj indd indh inda indb inswd inji induc insog
$LOAD dpu btu epsu cap vcp qfu_s xf_s df salvcm WtoEnv_V OU extcc qfa_s tst_cap vch vdesc
$LOAD pumpcap treacap descap extpc exttc extdc maxsld wwqc wwsc rr
$GDXIN
* Agricultural data (VALUE):
$call GDXXRW i=INPUT-AGRICULTURE.xlsx o=MYWAS-VALUE_in1.gdx index=Layout!a4
$GDXIN MYWAS-VALUE_in1.gdx
$LOAD A bta epsa indl miuL miuIn miuEx Pin PimA PimB Im_L Pex Y_s Im_s
$LOAD po E Y_Max apa1 apa2 apa3 apa4 apa5 phi teta psi xsi tl w wr
$LOAD is_lab is_lp for_lab for_lp pdc for_ll xg_s indcp slst QAB
$GDXIN

* Calculate the last year of the time sequence and associated time references
    TLAST(t) =  ord(t) eq card(t);
    TFIRST(t) = ord(t) eq 1;
    TALLBLAST(t) = TLAST(t) - 1;
    TALLBFIRST(t) = TFIRST(t) - 1;

Variables

   z             Total Net Economic Welfare

   UMben(j,t)    Benefits of households and industry from water -- the area under the demand curve (M$\year)
   Y(o,t)        Total yield by crop and year (Ton\year)
   Agben(t)      Total Agriculture benefit: Local market consumption+farmers' profits (Local+Industrial+Export)
   ImA(o,t)      An Import quantity by crop and year without tariff (Ton\year)
   ImB(o,t)      An Import quantity by crop and year include tariff (Ton\year)

   xf(j,i,t)     A Quantity of water transferred between two Nodes (MCM\year)
   qfu(u,t)      The total quantity of water used in an Urban demand area (MCM\year)
   qfa(j,t)      The Total quantity of water used in an Agricultural demand area (MCM\year)

   xg(j,o,t)     Allocation land variable by crop and agriculture demand area (Dunam\year)

   slp(j,i,t)    The Salinity level of water in a Pipeline (dS\m)
   slj(j,t)      The Salinity level of water in a Node (dS\m)

   Acap(j,i,t)   Cumulative Capacity of a Pipeline (MCM)
   ApumpC(j,t)   Cumulative Pumping Capacity of a Natural water source (MCM)
   AtreaC(j,t)   Cumulative Treatment Capacity of a Treatment plant (MCM)
   AdesC(j,t)    Cumulative Desalination Capacity of a Desalination plant (MCM)

   ofl(j,t)      Overflow in cases where net inflow exceeds available storage (MCM\year)
   ysf(j,t)      Fresh water source Storage at time t (MCM\year)
   AB_Q(j,t)     Additional Benefits (fishponds) Quantity (MCM\year)
   WtoEnv(j,t)   The amount of water discharged to the environment (MCM\year)
  ;

Positive variables UMben, Y, Aben, ImA, ImB, xf, qfu, qfa, xg, slp, slj, Acap, ApumpC, AtreaC, AdesC, ofl, ysf, AB_Q, WtoEnv
 ;
* Definition of initial values:
  xf.l(j,i,t)=xf_s(j,i,t);
  qfu.l(u,t)=qfu_s(u,t);
  qfa.l(j,t)=qfa_s(j,t);
  xg.l(j,o,t)=xg_s(j,o);
  Y.l(o,t)=Y_s(o,t);
  ImA.l(o,t)=Im_s(o,t);
  slj.l(j,t)$inda(j)= slst(j);
Equations

   Net_Welfare      Objective function

*           ++++++++ Model Equations Description +++++++

   Urb_C(j,t)       The Urban benefits -- area under the demand curve.
   Ag_C(t)          The Agriculture benefits (area under the demand curve).
   Y_C(o,t)         The Agriculture production function calculation.
   QFU_M(u,t)       Lower bound for water quantity in an urban demand ('epsu').
   QFA_M(o,t)       Lower bound for agricultural produce which is consumed in the local market ('epsa').
   ImA_Limit(o,t)   Non-tariff import quota.
   StorC_T1(j,t)    Capacity constraint on min storage capacity of storage for time t1.
   StorC_T(j,t)     Capacity constraint on min storage capacity of storage for time greater than t1.
   Storage_Cap(j,t) Constraint on the operational storage to not exceed the storage capacity.
   OverFlow(j,t)    Verify that overflow variable would be employed only when the storage capacity is met.
   AB_C(j,t)        Additional Benefits (fishponds) Calculation.
   Tot_J(j,t)       Total water outflowing from an NWC Junction does not exceed the inflow into the Junction.
   Tot_D(j,t)       Total water used by an urban demand area (households & industrial) does not exceed the inflow into that demand area (j).
   Tot_H(j,t)       Total water outflowing from a treatment plant equals the inflow into it minus the amount discharged to the environment.
   Tot_U(j,t)       Total water outflowing from an Urban demand area (households & industrial) equals the amount used multiplied by a conversion factor ('wwqc').
   Tot_A(j,t)       Total water available at an Agricultural area equals the inflow into that area ('qfa' definition).
   Tot_B(j,t)       Total water available at a Brackish water source does not exceed the Recharge of that source.
   Tot_des(j,i,t)   Total water outflowing from a Desalination plant (GWD or RWD only) equals the inflow into it multipled by the Recovery Rate ('rr').
   Reverse_X(j,i,t) Prevents two-way water flow at the same time in the NWC.
* Infrastructure  expansions:
* The base time is t0, hence, the first expansion can take place in t1.
* This is ensured by the following equations system:
   Conveyance(j,i,t)       Limitation of the Conveyance system
   Diff_GT0(j,i,t)         Preventing conveyance infrastructures shrinkage.
   Conveyance_Ex(j,i,t)    The minimum Conveyance capacity is at least as larage as the initial capacity.
   Pump_Cap(j,t)           Pumping Capacity constraint.
   Diff_PumpGT0(j,t)       Preventing pumping infrastructures shrinkage.
   Pump_Ex(j,t)            The minimum Pumping capacity is at least as larage as the initial capacity.
   Treat_Cap(j,t)          Treatment Capacity of wastewater treatment plant constraint.
   Diff_TreatGT0           Preventing wastewater treatment infrastructures shrinkage.
   Treat_Ex(j,t)           The minimum WWTP capacity is at least as larage as the initial capacity.
   Des_Cap(j,t)            Desalination capacity constraint.
   Diff_DesGT0             Preventing desalination infrastructures shrinkage.
   Des_Ex(j,t)             The minimum Desalination capacity is at least as larage as the initial capacity.
   Des_NonDec0(j,i,t)      Water desalination quantity at FIRST period cannot be less than existing capacity.
   Des_NonDec(j,i,t)       Water desalination quantity at time t>1 cannot be less than that at time t-1.

*** Salvage Value conditions ***
   AQ_STATE1(j,t)      Maximum deficit of aquifer for all time periods but the final one.
   AQ_STATE2(j,t)      End condition of the aquifer in the final time period
*** Water Quality Constraints ***
* The following five equations define water quality in terms of salinity:
   Salinity_dp(i,j,t)  Defining the salinity level at Pipe line that is connected to an Urban demand area (sewer).
   Salinity_p(i,j,t)   Defining the salinity level at Pipe line that is connected to any Node but Urban and Agriculture areas.
   Salinity_j0(j,t)    Defining the salinity level at the Sea of Galilee (variable).
   Salinity_j1(j,t)    Defining the salinity level at water source Nodes: natural water sources and desalination plants (parameter).
   Salinity_j2(j,t)    Defining the salinity level at non-source Nodes: demand areas and WWTPs (variable).
   Salinity_MAXD(j,t)  Limiting the salinity level of water thatis  delivered to an Urban demand area.

*** Agricultural Constraints ***
   Tot_Land(j,t)     The Maximum used land in an Agricultural area does not exceed the total available land in the area.
   Water_l(j,t)      The Maximum used water in an Agricultural area is the same as variable 'qfa'.
   Max_for_l(j,t)    The Maximum Foreign Labor force used in an Agriculture area does not exceed the total labor quota available in that area.
;

*                  ++++++++++++++++ OBJECTIVE FUNCTION STARTS +++++++++++++++++

  Net_Welfare.. z =E=
* Benefits:
       sum(t, df(t)*(sum(j$indd(j), UMben(j,t))+ Agben(t)
* Salvage value:
       +sum(j$(indf(j) and TLAST(t)), salvcm(j)*ysf(j,t))
* Water consumption of other sectors: Jordan Kingdom, PA  and nature:
       -sum(j$indf(j), AB_Q(j,t)*P_AB)-sum(j$indh(j), WtoEnv(j,t)*WtoEnv_V(j))
* Operational costs:
       -sum((j,i)$inji(j,i), xf(j,i,t)*vcp(j,i))
       -sum((j,i)$(indf(j) and inji(j,i) and TFIRST(t)), xf(j,i,t)*(Varpump_c(j)-iscf(j)*vocf(j)))
       -sum((j,i)$(indf(j) and inji(j,i) and TALLBFIRST(t)), xf(j,i,t)*(Varpump_c(j)-ysf(j,t-1)*vocf(j)))
       -sum((j,i)$(indb(j) and inji(j,i)), xf(j,i,t)*occonst(j))
       -sum((j,i)$(indh(i) and inji(j,i)), xf(j,i,t)*vch(i))
       -sum((j,i)$(inswd(j) and inji(j,i)), xf(j,i,t)*vdesc(j))
       -sum((j,i)$(inddp(i) and inji(j,i) and (1-inswd(i))), xf(j,i,t)*vdesc(i))
* Capacity expansion costs:
       -sum((j,i), extcc(j,i)*(Acap(j,i,t)-cap(j,i)))
       -sum(j, extpc(j)*(ApumpC(j,t)-pumpcap(j)))
       -sum(j, exttc(j)*(AtreaC(j,t)-treacap(j)))
       -sum(j, extdc(j)*(AdesC(j,t)-descap(j)))))
;
*                    ++++++++++++++ OBJECTIVE FUNCTION ENDS +++++++++++++++


*                                 ////// Constraints\\\\\\
*** Urban demand calculation ***
   Urb_C(j,t)$indd(j)..                    UMben(j,t) =E= sum(u$induc(j,u), (dpu(u,t)/(btu(u)+1))*
                                           (((qfu(u,t))**(btu(u)+1))-epsu(u,t)**(btu(u)+1)));
*** Agriculture benefits calculation ***
  Ag_C(t)..     Agben(t) =E=
     0.000001*
  (sum(o$indl(o), (A(o,t)/(bta(o)+1))*((Y(o,t)*miuL(o)+ImA(o,t)+ImB(o,t))**(bta(o)+1))-ImA(o,t)*PimA(o)-ImB(o,t)*PimB(o))
  +sum(o, Y(o,t)*miuIn(o)*Pin(o)+Y(o,t)*miuEx(o)*PEx(o))
  +sum((j,o)$(inda(j) and indcp(j,o)), xg(j,o,t)*(-is_lab(o)*is_lp(o)-for_lab(o)*for_lp(o)-pdc(j,o) -psi(j,o)-xsi(j,o)*Xg(j,o,t))));

   Y_C(o,t)..      Y(o,t) =E= sum(j$(inda(j) and indcp(j,o)), xg(j,o,t)*(Y_Max(j,o)/
                             (1+apa1(j,o)*((apa5(j,o)*((slj(j,t)
                   *w(j,o)+wr(j,o)*slr)/(w(j,o)+wr(j,o)))+apa2(j,o)*((w(j,o)+wr(j,o))**apa3(j,o)))**apa4(j,o)))));

*** Minimum conditions ***
   QFU_M(u,t)..                           qfu(u,t) =G= epsu(u,t);
   QFA_M(o,t)$indl(o)..                   Y(o,t)*miuL(o)+ImA(o,t)+ImB(o,t) =G= epsa(o,t);
   ImA_Limit(o,t)$indl(o)..               ImA(o,t) =L= Im_L(o);
*** Quantity Constraints ***
   StorC_T1(j,t)$(indf(j) and TFIRST(t))..     sum(i$inji(j,i), xf(j,i,t)) =L= iscf(j)+r(j,t)-ysf(j,t)-ofl(j,t)-AB_Q(j,t);
   StorC_T(j,t)$(indf(j) and TALLBFIRST(t))..  sum(i$inji(j,i), xf(j,i,t)) =L= ysf(j,t-1)+r(j,t)-ysf(j,t)-ofl(j,t)-AB_Q(j,t);
   Storage_cap(j,t)$indf(j)..                  ysf(j,t) =L= tst_cap(j);
   OverFlow(j,t)$indf(j)..                     ofl(j,t)*(tst_cap(j)-ysf(j,t)) =E= 0;
   AB_C(j,t)$indf(j)..                           AB_Q(j,t) =E= OU(j);
*** Junction Constraints ***
   Tot_J(j,t)$indj(j)..          sum(i$inji(j,i), xf(j,i,t)) =L= sum(i$inji(i,j), xf(i,j,t));
   Tot_D(j,t)$indd(j)..          sum(u$induc(j,u), qfu(u,t)) =L= sum(i$inji(i,j), xf(i,j,t));
   Tot_U(j,t)$indd(j)..          sum(i$inji(j,i), xf(j,i,t)) =E= sum(u$induc(j,u), qfu(u,t)*wwqc(u));
   Tot_H(j,t)$indh(j)..          sum(i$inji(j,i), xf(j,i,t))+ WtoEnv(j,t)=E= sum(i$inji(i,j), xf(i,j,t));
   Tot_A(j,t)$inda(j)..          qfa(j,t)+QAB(j) =E= sum(i$inji(i,j),xf(i,j,t));
   Tot_B(j,t)$indb(j)..          sum(i$inji(j,i), xf(j,i,t)) =L= r(j,t);
   Tot_des(j,i,t)$(inddp(j) and inji(i,j))..       sum(n$inji(j,n), xf(j,n,t)) =E= xf(i,j,t)*rr(j);
   Reverse_X(j,i,t)$(inji(j,i) and inji(i,j))..      xf(j,i,t)*xf(i,j,t)=E=0;
*** Conveyance Constraints ***
   Conveyance(j,i,t)$inji(j,i)..                                  xf(j,i,t) =L= acap(j,i,t);
   Diff_GT0(j,i,t)$(inji(j,i) and TALLBFIRST(t))..                acap(j,i,t) =G= acap(j,i,t-1);
   Conveyance_Ex(j,i,t)$(inji(j,i))..                             acap(j,i,t) =G= cap(j,i);
*** Facility Capability Constraints and Expansions ***
   Pump_Cap(j,t)$(indf(j) or indb(j))..                           sum(i$inji(j,i), xf(j,i,t)) =L= ApumpC(j,t);
   Diff_PumpGT0(j,t)$((indf(j) or indb(j)) and TALLBFIRST(t))..   ApumpC(j,t) =G= ApumpC(j,t-1);
   Pump_Ex(j,t)$(indf(j) or indb(j))..                            ApumpC(j,t) =G= pumpcap(j);

   Treat_Cap(j,t)$indh(j)..                                       sum(i$inji(i,j), xf(i,j,t)) =L= AtreaC(j,t);
   Diff_TreatGT0(j,t)$(indh(j) and TALLBFIRST(t))..               AtreaC(j,t) =G= AtreaC(j,t-1);
   Treat_Ex(j,t)$indh(j)..                                        AtreaC(j,t) =G= treacap(j);

   Des_Cap(j,t)$inddp(j)..                                        sum(i$inji(j,i), xf(j,i,t)) =L= AdesC(j,t);
   Diff_DesGT0(j,t)$(inddp(j) and TALLBFIRST(t))..                AdesC(j,t) =G= AdesC(j,t-1);
   Des_Ex(j,t)$inddp(j)..                                         AdesC(j,t) =G= descap(j);

   Des_NonDec0(j,i,t)$(inddp(j) and inji(j,i) and TFIRST(t))..    sum(n$inji(j,n),xf(j,n,t)) =G= descap(j);
   Des_NonDec(j,i,t)$(inddp(j) and inji(j,i) and TALLBFIRST(t)).. sum(n$inji(j,n), xf(j,n,t)) =G= sum(n$inji(j,n), xf(j,n,t-1))  ;
*** Salvage Value conditions ***
   AQ_STATE1(j,t)$(indf(j) and TALLBLAST(t))..      ysf(j,t)/tst_cap(j) =G= AQ_MAXDEF(j);
   AQ_STATE2(j,t)$(indf(j) and TLAST(t))..          ysf(j,t)/tst_cap(j) =G= AQ_ENDV;
***Salinity Constraints***

 Salinity_dp(j,i,t)$(indd(j) and inji(j,i))..     slp(j,i,t) =G= slj(j,t)+wwsc(j);

 Salinity_p(j,i,t)$((1-inda(j)-indd(j)) and inji(j,i))..     slp(j,i,t) =G= slj(j,t);

 Salinity_j0(j,t)$(indf(j) and insog(j))..     slj(j,t) =G= slf(j,t)-0.0007*ysf(j,t);
 Salinity_j1(j,t)$((indf(j) or indb(j) or inddp(j)) and (1-insog(j)))..   slj(j,t) =G= slf(j,t)+sldp(j);
 Salinity_j2(j,t)$(indd(j) or inda(j) or indh(j) or indj(j))..
          slj(j,t) =G= (sum(i$inji(i,j), xf(i,j,t)*slp(i,j,t)+const*slp(i,j,t)))
                      /(sum(i$inji(i,j), xf(i,j,t))+const);

 Salinity_MAXD(j,t)$indd(j)..                     slj(j,t) =L= maxsld(j);

***Agriculture elements***
   Tot_Land(j,t)$inda(j)..      sum(o, xg(j,o,t)) =L= tl(j);
   Water_l(j,t)$inda(j)..       sum(o$indcp(j,o), xg(j,o,t)*W(j,o))*0.000001 =E= qfa(j,t) ;
   Max_for_l(j,t)$inda(j)..     sum(o, xg(j,o,t)*for_lab(o)) =L= for_ll(j);

Model AWUAS /All/;
Option NLP = conopt4
reslim = 9999999999999;
Solve AWUAS Maximizing z using NLP;

******************************* Results ****************************************
Parameters
  lUrb(j,t)        Total benefit from Urban demand by areas (M$\year)
  lAgb(t)          Total benefit from the consumption of Agricultural products (M$\year)
  mf(j,t)          The Shadow price of quantity at a Fresh water source t=1 ($\CM)
  mf2(j,t)         The Shadow price of quantity at a Fresh water source t>1 ($\CM)
  mb(j,t)          The Shadow price of quantity at a Brackish water source ($\CM)
  mj(j,t)          The Shadow price of quantity at an NWC Junction ($\CM)
  md(j,t)          The Shadow price of quantity at an Urban demand area ($\CM)
  mu(j,t)          The Shadow price of quantity for the sewage created in an Urban demand area ($\CM)
  mh(j,t)          The Shadow price of quantity at a treatment plant ($\CM)
  ma(j,t)          The Shadow price of quantity at an Agriculture demand area ($\CM)
  mdp(j,i,t)       The Shadow price of quantity at a Desalination plant  (GWD and RWD) ($\CM)
  mCon(j,i,t)      The Shadow price of capacity of a pipe line ($\CM)
  mDES(j,t)        The Shadow price of capacity of a Desalination plant (GWD and SWD) ($\CM)
  Pcap(j,t)        The Shadow price of capacity of a pumping station ($\CM)
  Tcap(j,t)        The Shadow price of capacity of a wastewater treatment plant ($\CM)
  AQS(j,t)         The amount of water available in the aquifer at time t (MCM)
  pum(u,t)         The Marginal value of the urban demand as a derivative of the demand curve ($\CM)
  pAg(o,t)         Price of agricultural produce of a crop supplied to the local market ($\Ton)
  q(j,i,t)         Quantity of water transferred between two junctions (MCM\year)
  qu(u,t)          Quantity of water used in an urban area (MCM\year)
  qa(j,t)          Quantity of water used in an agriculture area (MCM\year)
  qj_F(j,t)        Quantity of water outflowing from a fresh water source (MCM\year)
  qj_B(j,t)        Quantity of water outflowing from a brackish water source (MCM\year)
  qj_DES(j,t)      Quantity of water outflowing from a desalination plant (MCM\year)
  qj_TP(j,t)       Quantity of water outflowing from a wastewater treatment plant (MCM\year)
  qExt(j,t)        Expansion amount in MCM per Node (e.g. pumping etc.)
  qExtC(j,i,t)     Expansion amount in MCM per Pipe line (capacity of conveyance)
  Tot_ExtC(j,t)    Total Expansion cost per Node (M$\year)
  conv_ExtC(j,i,t) Total Expansion cost per pipeline (M$\year)
  Tot_PumpC(j,t)   Pumping variable cost of Fresh\Brackish water source (M$\year)
  Cons_PumpC(j,t)  Pumping constant cost (M$\year)
  Tot_DesC(j,t)    Total desalination cost per desalination plant (M$\year)
  Tot_convC(j,i,t) Total conveyance cost per pipe line (M$\year)
  Tot_treatC(j,t)  Total treatment cost per treatment plant (M$\year)
  slx(j,i,t)       Water's salinity level of a pipeline (dS\m)
  sln(j,t)         Water's salinity level of a Node (dS\m)
  msldp(j,i,t)     Shadow price of water salinity at a pipeline that is connected to an urban area (M$\dS\m\year)
  mslp(j,i,t)      Shadow price of water salinity at a pipeline that is connected to a treatment plant (M$\dS\m\year)
  mslj1(j,t)       Shadow price of water salinity of a water sources (M$\dS\m\year)
  mslj2(j,t)       Shadow price of water salinity of others non-source Nodes (M$\dS\m\year)

  ImRA(o,t)        Import amount A (non-tariff) by crop (Ton\year)
  ImRB(o,t)        Import amount B (including tariff) by crop (Ton\year)
  YRR(o,t)         Total yield variable Y- Yield (Ton\year)
  YR(j,o,t)        Yield calculated- for other calculations. Equal to 'YRR' (Ton\year) (external calculation)
  Y_pd(j,o,t)      Yield per dunam (Ton\Dunam)
  vop(j,o,t)       Value of production for each crop o at each agricultural demand area j (M$\year)
  vop_pd(j,o,t)    Production per dunam for each crop o at each agricultural demand area j (M$\Dunam)
  rpc(o,t)         Revenue for each crop (M$\year)
  Rxg(j,o,t)       Land allocated to each crop (Dunam\year)

  m_land(j,t)      Shadow price of the agriculture land constraint (M$\Dunam)
  m_forl(j,t)      Shadow price of the agriculture foreign-labor constraint (M$\day)
  m_water(j,t)     Shadow price of the agriculture water constraint ($\CM)
  Tot_agriC(j,o,t) Total agriculture production costs by crop type (M$\year)
;
*** Results Execute ***
 lUrb(j,t)=  UMben.l(j,t);
 lAgb(t)= Agben.l(t);
 mf(j,t)=  StorC_T1.m(j,t);
 mf2(j,t)=  StorC_T.m(j,t);
 mb(j,t)=  Tot_B.m(j,t);
 mj(j,t)=  Tot_J.m(j,t);
 md(j,t)=  Tot_D.m(j,t);
 mu(j,t)=  Tot_U.m(j,t);
 mh(j,t)=  Tot_H.m(j,t);
 ma(j,t)= Tot_A.m(j,t);
 mdp(j,i,t)= Tot_des.m(j,i,t);
 mCon(j,i,t)= Conveyance.m(j,i,t);
 mDES(j,t)= Des_Cap.m(j,t);
 AQS(j,t)$indf(j)= ysf.l(j,t);
 pum(u,t)=dpu(u,t)*(qfu.l(u,t)**btu(u));
 pAg(o,t)$indl(o)= A(o,t)*(Y.l(o,t)*MiuL(o)+ImA.l(o,t)+ImB.l(o,t))**bta(o);
 q(j,i,t)= xf.l(j,i,t);
 qu(u,t)= qfu.l(u,t);
 qa(j,t)= qfa.l(j,t);
 qj_F(j,t)$indf(j)= sum(i$inji(j,i), xf.l(j,i,t));
 qj_B(j,t)$indb(j)= sum(i$inji(j,i), xf.l(j,i,t));
 qj_DES(j,t)$inddp(j)= sum(i$inji(j,i), xf.l(j,i,t));
 qj_TP(j,t)$indh(j)= sum(i$inji(j,i), xf.l(j,i,t));
 qExt(j,t)=  (ApumpC.l(j,t)-pumpcap(j))
             +(AtreaC.l(j,t)-treacap(j))
             +(AdesC.l(j,t)-descap(j)) ;

 Pcap(j,t)= Pump_Cap.m(j,t) ;
 Tcap(j,t)= Treat_Cap.m(j,t);
 qExtC(j,i,t)= Acap.l(j,i,t)-cap(j,i);
 slx(j,i,t)= slp.l(j,i,t);
 sln(j,t)= slj.l(j,t);

 msldp(j,i,t)= salinity_dp.m(j,i,t);
 mslp(j,i,t)= salinity_p.m(j,i,t);
 mslj1(j,t)= salinity_j1.m(j,t);
 mslj2(j,t)= salinity_j2.m(j,t);

 conv_ExtC(j,i,t)$inji(j,i)= extcc(j,i)*(Acap.l(j,i,t)-cap(j,i));
 Tot_PumpC(j,t)= sum(i$(indf(j) and inji(j,i) and TFIRST(t)), xf.l(j,i,t)*(Varpump_c(j)-iscf(j)*vocf(j)))+sum(i$(indb(j) and inji(j,i)), xf.l(j,i,t)*occonst(j))
                +sum(i$(indf(j) and inji(j,i) and TALLBFIRST(t)), xf.l(j,i,t)*(Varpump_c(j)-ysf.l(j,t-1)*vocf(j))) ;
 Cons_PumpC(j,t)= sum(i$(indf(j) and inji(j,i) and TFIRST(t)), xf.l(j,i,t)*occonst(j))
                +sum(i$(indf(j) and inji(j,i) and TALLBFIRST(t)), xf.l(j,i,t)*occonst(j)) ;
 Tot_desC(j,t)$inddp(j)= sum(i$inji(j,i), xf.l(j,i,t)*vdesc(j));
 Tot_convC(j,i,t)$inji(j,i)=  xf.l(j,i,t)*vcp(j,i);
 Tot_treatC(i,t)= sum(j$(indh(i) and inji(j,i)), xf.l(j,i,t)*vch(i));

 Tot_ExtC(j,t)=   extpc(j)*(ApumpC.l(j,t)-pumpcap(j))
                 + exttc(j)*(AtreaC.l(j,t)-treacap(j))
                 + extdc(j)*(AdesC.l(j,t)-descap(j)) ;

 ImRA(o,t)$indl(o)= ImA.l(o,t);
 ImRB(o,t)$indl(o)= ImB.l(o,t);
 YRR(o,t)= Y.l(o,t);
 YR(j,o,t)$inda(j)=xg.l(j,o,t)*((E(j,o)*teta(j,o))/(1+apa1(j,o)*((apa5(j,o)*((slj.l(j,t)
      *w(j,o)+wr(j,o)*slr)/(w(j,o)+wr(j,o)))+apa2(j,o)*((w(j,o)+wr(j,o))**apa3(j,o)))**apa4(j,o))));

 Y_pd(j,o,t)$(inda(j) and indcp(j,o))=YR(j,o,t)/ Xg.l(j,o,t);
 vop_pd(j,o,t)$inda(j)= (pAg(o,t)*miuL(o)+miuIn(o)*Pin(o)+miuEx(o)*PEx(o))*Y_pd(j,o,t)*0.000001;
 vop(j,o,t)= 0.000001*YR(j,o,t)*(miuL(o)*pAg(o,t)+miuIn(o)*Pin(o)+miuEx(o)*PEx(o));
 rpc(o,t)=  0.000001*(Y.l(o,t)*(MiuL(o)*pAg(o,t)+miuIn(o)*Pin(o)+miuEx(o)*PEx(o))
       +sum(j$(inda(j) and indcp(j,o)),Xg.l(j,o,t)*(-is_lab(o)*is_lp(o)-for_lab(o)*for_lp(o)-pdc(j,o) -psi(j,o)-xsi(j,o)*Xg.l(j,o,t))));

  Rxg(j,o,t)= xg.l(j,o,t);

  m_land(j,t)=    Tot_Land.m(j,t);
  m_water(j,t) =  Water_l.m(j,t);
  m_forl(j,t) =   Max_for_l.m(j,t);

  Tot_agriC(j,o,t)=  0.000001*Xg.l(j,o,t)*(is_lab(o)*is_lp(o)+for_lab(o)*for_lp(o)+pdc(j,o)+psi(j,o)+xsi(j,o)*xg.l(j,o,t));

Execute_Unload  'MYWAS-VALUE_OUTPUT.GDX'
 lUrb, lAgb, mf, mf2, mb, mj, md, mu, mh, ma, mdp, mcon, mDES, pum, pAg, AQS,
 q, qu, qa, qj_F, qj_B, qj_DES, qj_TP,qExt, Pcap, Tcap,
 qExtC, Tot_ExtC, conv_ExtC, Tot_PumpC, Cons_PumpC, Tot_convC, Tot_desC, Tot_treatC,
 slx, sln, msldp, mslp, mslj1, mslj2,
 Rxg, ImRA, ImRB, YR, YRR, Y_pd, vop_pd, vop, rpc, m_land, m_forl, m_water, Tot_agriC
 ;

Execute  'GDXXRW I=MYWAS-VALUE_OUTPUT.gdx o=MYWAS-VALUE_OUTPUT.xlsx INDEX=layout!a3';




